@@ -11,9 +11,13 @@ NULL
 #' @import methods
 NULL
 
-#' @import Rcpp
+#' @import CMplot
 NULL
 
+#' @importFrom CMplot CMplot
+#' @export
+CMplot::CMplot
+
 #' @importFrom stringr str_extract_all
 NULL
 #' @importFrom stringr str_replace_all
